---
name: New process proposal
about: Propose a new process with detailed specifics (name, description, parameters,
  return value etc.). To just pitch an idea without a lot of details, please fill
  a "normal" issue.
title: ''
labels: new process
assignees: ''

---

**Proposed Process ID:** ... (alphanumeric + underscore only)

## Context
Give some context and an introduction of what this process is needed for, e.g. use cases.

## Summary
... (max. 60 chars)

## Description
... (min. 55 chars, Markdown allowed)

## Parameters

### `param1` (name of first parameter, alphanumeric + underscore only)

**Optional:** no/yes, default: ... (default value only required for "yes")

#### Description
... (Markdown allowed)

#### Data Type
boolean/number/string/array/object/null
... (include additional constraints, e.g. min/max values for numbers or a list of allowed values for strings)

### `param2` (name of second parameter, copy this template for additional parameters)

**Optional:** no/yes, default: ... (default value only required for "yes")

#### Description
...

#### Data Type
...

## Return Value
### Description
... (Markdown allowed)

### Data Type
boolean/number/string/array/object/null
... (include additional constraints, e.g. min/max values for numbers or a list of allowed values for strings)

## Categories (optional)
* ...
* ...

## Links to additional resources (optional)
* https://...

## Examples (optional)
* ...

## Details about exceptions mentioned in the description (optional)
* ...
